@@ -19,34 +19,28 @@
 */
 
 #include "abstractengine.h"
+#include "lskat_debug.h"
 
 // Qt includes
 
 // KDE includes
-#include <kdebug.h>
-
 
 // Constructor for the game document/engine
-AbstractEngine::AbstractEngine(QWidget* parent)
+AbstractEngine::AbstractEngine(QWidget *parent)
                : QObject(parent)
 {
-  mGameStatus = Stopped;
-  mPlayers.clear();
+    mGameStatus = Stopped;
+    mPlayers.clear();
 }
 
-
 // Add a player to the game
-void AbstractEngine::addPlayer(int no, Player* player)
+void AbstractEngine::addPlayer(int no, Player *player)
 {
-  mPlayers[no] = player;
+    mPlayers[no] = player;
 }
 
-
 // Retrieve the player of the given number.
-Player* AbstractEngine::player(int no)
+Player *AbstractEngine::player(int no)
 {
-  return mPlayers[no];
+    return mPlayers[no];
 }
-
-
-#include "abstractengine.moc"
